@@ -5,26 +5,23 @@ import uuid
 import logging
 import subprocess
 from pathlib import Path
-from typing import TypedDict, Optional, Dict, List, Any
+from typing import Optional, Any
 from rich.console import Console
 from machineconfig.utils.scheduler import Scheduler
 from machineconfig.cluster.sessions_managers.wt_local import WTLayoutGenerator
 from machineconfig.utils.schemas.layouts.layout_types import LayoutConfig
 from machineconfig.cluster.sessions_managers.zellij_utils.monitoring_types import (
-    StartResult, GlobalSummary, ActiveSessionInfo, CommandStatus, CommandSummary
+    StartResult, GlobalSummary, ActiveSessionInfo
 )
 
 
-class WTSessionReport(TypedDict):
-    session_status: Dict[str, Any]  # WT-specific session status
-    commands_status: Dict[str, CommandStatus]
-    summary: CommandSummary
+
 
 logging.basicConfig(level=logging.INFO)
 logger = logging.getLogger(__name__)
 console = Console()
+TMP_SERIALIZATION_DIR = Path.home() / "tmp_results" / "wt_sessions" / "serialized"
 
-TMP_SERIALIZATION_DIR = Path.home().joinpath("tmp_results", "session_manager", "wt", "local_manager")
 
 
 class WTLocalManager:
@@ -41,21 +38,22 @@ class WTLocalManager:
         """
         self.session_name_prefix = session_name_prefix
         self.session_layouts = session_layouts  # Store the original config
-        self.managers: List[WTLayoutGenerator] = []
+        self.managers: list[WTLayoutGenerator] = []
 
         # Create a WTLayoutGenerator for each session
         for layout_config in session_layouts:
-            manager = WTLayoutGenerator()
-            manager.create_wt_layout(layout_config=layout_config, output_dir=None)
+            session_name = layout_config["layoutName"]
+            manager = WTLayoutGenerator(layout_config=layout_config, session_name=session_name)
+            manager.create_layout_file()
             self.managers.append(manager)
 
         logger.info(f"Initialized WTLocalManager with {len(self.managers)} sessions")
 
-    def get_all_session_names(self) -> List[str]:
+    def get_all_session_names(self) -> list[str]:
         """Get all managed session names."""
-        return [manager.session_name for manager in self.managers if manager.session_name is not None]
+        return [manager.session_name for manager in self.managers]
 
-    def start_all_sessions(self) -> Dict[str, StartResult]:
+    def start_all_sessions(self) -> dict[str, StartResult]:
         """Start all Windows Terminal sessions with their layouts."""
         results = {}
         for manager in self.managers:
@@ -86,7 +84,7 @@ class WTLocalManager:
 
         return results
 
-    def kill_all_sessions(self) -> Dict[str, StartResult]:
+    def kill_all_sessions(self) -> dict[str, StartResult]:
         """Kill all managed Windows Terminal sessions."""
         results = {}
         for manager in self.managers:
@@ -130,7 +128,7 @@ class WTLocalManager:
                 commands.append("")
             return "\n".join(commands)
 
-    def check_all_sessions_status(self) -> Dict[str, WTSessionReport]:
+    def check_all_sessions_status(self) -> dict[str, dict[str, Any]]:
         """Check the status of all sessions and their commands."""
         status_report = {}
 
@@ -361,9 +359,7 @@ class WTLocalManager:
                     manager_data = json.loads(text)
 
                     # Recreate the manager
-                    manager = WTLayoutGenerator()
-                    manager.session_name = manager_data["session_name"]
-                    manager.layout_config = manager_data["layout_config"]
+                    manager = WTLayoutGenerator(layout_config=manager_data["layout_config"], session_name=manager_data["session_name"])
                     manager.script_path = manager_data["script_path"]
 
                     instance.managers.append(manager)
@@ -375,7 +371,7 @@ class WTLocalManager:
         return instance
 
     @staticmethod
-    def list_saved_sessions() -> List[str]:
+    def list_saved_sessions() -> list[str]:
         """List all saved session IDs."""
         if not TMP_SERIALIZATION_DIR.exists():
             return []
@@ -406,7 +402,7 @@ class WTLocalManager:
             logger.error(f"Failed to delete session {session_id}: {e}")
             return False
 
-    def list_active_sessions(self) -> List[ActiveSessionInfo]:
+    def list_active_sessions(self) -> list[ActiveSessionInfo]:
         """List currently active Windows Terminal sessions managed by this instance."""
         active_sessions = []
 
@@ -448,7 +444,7 @@ class WTLocalManager:
 
         return active_sessions
 
-    def get_wt_overview(self) -> Dict[str, Any]:
+    def get_wt_overview(self) -> dict[str, Any]:
         """Get overview of all Windows Terminal windows and processes."""
         try:
             result = subprocess.run(
