@@ -1,7 +1,7 @@
 from typing import Literal, TypeAlias, Union
 
 # AI/LLM Tools - AI-powered coding and chat assistants
-PACKAGES_AI_TOOLS = [
+BUNDLE_AI = [
     "aider",
     "github-copilot-cli",
     "gemini",
@@ -11,18 +11,12 @@ PACKAGES_AI_TOOLS = [
     "chatgpt",
     "mods",
     "q",
+    "qwen-code",
     "cursor-cli",
     "droid",
     "auggie",
 ]
 
-# Tunneling/Port Forwarding - Tools for exposing local services
-PACKAGES_TUNNELING = [
-    "ngrok",
-    "devtunnel",
-    "cloudflared",
-    "forward-cli",
-]
 
 # Terminal Emulators & Shells - Terminal applications, emulators, and shell environments
 PACKAGES_TERMINAL_EMULATORS = [
@@ -41,6 +35,8 @@ PACKAGES_BROWSERS = [
     "bypass-paywalls-chrome",
     "browsh",
     "carbonyl",
+    "m365",
+    "zoomit",
 ]
 
 # Code Editors & IDEs - Code editing tools
@@ -51,16 +47,7 @@ PACKAGES_CODE_EDITORS = [
     "lvim",
 ]
 
-# Presentation & Text UI Tools - Markdown viewers, presentations, prompts, and text decoration
-PACKAGES_PRESENTATION = [
-    "patat",
-    "marp",
-    "presenterm",
-    "glow",
-    "gum",
-    "boxes",
-    "hx",
-]
+
 
 # Database Tools - Database clients and visualizers
 PACKAGES_DATABASE = [
@@ -70,12 +57,6 @@ PACKAGES_DATABASE = [
     "duckdb",
 ]
 
-# Documentation & Conversion - Document conversion, diagram tools, and fast file operations
-PACKAGES_DOC_CONVERSION = [
-    "mermaid-cli",
-    "html2markdown",
-    "pandoc",
-]
 
 # Media & Entertainment - Music players and media tools
 PACKAGES_MEDIA = [
@@ -88,8 +69,10 @@ PACKAGES_MEDIA = [
 
 # File Sharing & Cloud - File sharing, transfer, backup, sync, and QR tools
 PACKAGES_FILE_SHARING = [
-    "cpz",
-    "rmz",
+    "ngrok",
+    "devtunnel",
+    "cloudflared",
+    "forward-cli",
     "ffsend",
     "portal",
     "qrcp",
@@ -108,14 +91,6 @@ PACKAGES_FILE_SHARING = [
 ]
 
 
-# Git & Docker Tools - Version control and container utilities
-PACKAGES_GIT_DOCKER_TOOLS = [
-    "lazygit",
-    "onefetch",
-    "gitcs",
-    "lazydocker",
-]
-
 # Development Tools - Various development utilities
 PACKAGES_DEV_UTILS = [
     "devcontainer",
@@ -126,6 +101,10 @@ PACKAGES_DEV_UTILS = [
 
 # Code Analysis, Git & Docs - Code analysis, statistics, documentation, and Git tools
 PACKAGES_CODE_ANALYSIS = [
+    "lazygit",
+    "onefetch",
+    "gitcs",
+    "lazydocker",
     "hyperfine",
     "kondo",
     "tokei",
@@ -134,6 +113,8 @@ PACKAGES_CODE_ANALYSIS = [
     "gitui",
     "delta",
     "gh",
+    "watchexec",
+    "jq",
 ]
 
 # Productivity & Utilities - Productivity tools, security, remote access, and terminal enhancements
@@ -141,16 +122,25 @@ PACKAGES_PRODUCTIVITY = [
     "espanso",
     "bitwarden",
     "openpomodoro-cli",
-    "just",
     "rustdesk",
+    "mermaid-cli",
+    "html2markdown",
+    "pandoc",
+    "patat",
+    "marp",
+    "presenterm",
+    "glow",
+    "gum",
+    "hx",
 ]
 
 # Miscellaneous Tools - Other tools
 PACKAGES_MISC_DEV = [
+    "lolcatjs",
+    "figlet-cli",
+    "boxes",
     "Gorilla",
-    "nerdfont",
     "Redis",
-    "winget",
     "transmission",
     "exa",
     "bytehound",
@@ -162,24 +152,6 @@ PACKAGES_MISC_DEV = [
     "nnn",
 ]
 
-# Main DEV package list - combines all subgroups
-PACKAGES_NAMES_DEV = [
-    *PACKAGES_AI_TOOLS,
-    *PACKAGES_TUNNELING,
-    *PACKAGES_TERMINAL_EMULATORS,
-    *PACKAGES_BROWSERS,
-    *PACKAGES_CODE_EDITORS,
-    *PACKAGES_PRESENTATION,
-    *PACKAGES_DATABASE,
-    *PACKAGES_DOC_CONVERSION,
-    *PACKAGES_MEDIA,
-    *PACKAGES_FILE_SHARING,
-    *PACKAGES_GIT_DOCKER_TOOLS,
-    *PACKAGES_DEV_UTILS,
-    *PACKAGES_CODE_ANALYSIS,
-    *PACKAGES_PRODUCTIVITY,
-    *PACKAGES_MISC_DEV,
-]
 
 # System & Network Monitoring - System resource monitors, process viewers, network analysis, and system info tools
 PACKAGES_SYSTEM_MONITORS = [
@@ -193,11 +165,26 @@ PACKAGES_SYSTEM_MONITORS = [
     "cpufetch",
     "fastfetch",
     "topgrade",
+    "speedtest",
 ]
 
 
-# File Tools - File browsing, navigation, listing, directory jumping, and disk usage analysis
-PACKAGES_FILE_TOOLS = [
+
+
+# Search & Archive Tools - File and content search utilities, archive management
+PACKAGES_FILE = [
+    "nerdfont",
+    "winget",
+    "fd",
+    "fzf",
+    "broot",
+    "rg",
+    "rga",
+    "ugrep",
+    "ouch",
+    "pistol",
+    "bat",
+    "viu",
     "xplr",
     "joshuto",
     "lf",
@@ -208,25 +195,8 @@ PACKAGES_FILE_TOOLS = [
     "diskonaut",
     "dua",
     "dust",
-]
-
-# File Viewers - File preview and viewing tools
-PACKAGES_FILE_VIEWERS = [
-    "pistol",
-    "bat",
-    "viu",
-]
-
-
-# Search & Archive Tools - File and content search utilities, archive management
-PACKAGES_SEARCH = [
-    "fd",
-    "fzf",
-    "broot",
-    "rg",
-    "rga",
-    "ugrep",
-    "ouch",
+    "cpz",
+    "rmz",
 ]
 
 # Terminal & Shell Enhancements - Terminal multiplexers, shell history, and prompts
@@ -235,41 +205,14 @@ PACKAGES_TERMINAL_SHELL = [
     "mprocs",
     "mcfly",
     "starship",
-    "lolcatjs",
-    "figlet-cli",
-]
-# Web Sharing - Share terminal over web
-PACKAGES_WEB_TERMINAL = [
     "gotty",
     "ttyd",
-]
-
-
-# Cloud & Utilities - Cloud storage, file watching, web terminal, and presentation tools
-PACKAGES_CLOUD_UTILS = [
     "rclone",
-    "watchexec",
-    "m365",
-    "zoomit",
-    "speedtest",
 ]
 
 
 
 
-# Main ESSENTIAL package list - combines all subgroups
-PACKAGES_NAMES_ESSENTIAL = [
-    *PACKAGES_CODE_ANALYSIS,
-    *PACKAGES_PRESENTATION,
-    *PACKAGES_FILE_VIEWERS,
-    *PACKAGES_FILE_TOOLS,
-    *PACKAGES_SYSTEM_MONITORS,
-    *PACKAGES_WEB_TERMINAL,
-    *PACKAGES_TERMINAL_SHELL,
-    *PACKAGES_SEARCH,
-    *PACKAGES_AI_TOOLS,
-    *PACKAGES_CLOUD_UTILS,
-]
 
 PACKAGE_GROUPS: TypeAlias = Literal[
     "ESSENTIAL",
@@ -297,31 +240,47 @@ PACKAGE_GROUPS: TypeAlias = Literal[
     "CLOUD_UTILS",
     "WEB_TERMINAL",
 ]
+
+
+
+# Main ESSENTIAL package list - combines all subgroups
+ESSENTIAL = [
+    *PACKAGES_CODE_ANALYSIS,
+    *PACKAGES_SYSTEM_MONITORS,
+    *PACKAGES_TERMINAL_SHELL,
+    *PACKAGES_FILE,
+    *BUNDLE_AI,
+]
+DEV = [
+    *PACKAGES_TERMINAL_EMULATORS,
+    *PACKAGES_BROWSERS,
+    *PACKAGES_CODE_EDITORS,
+    *PACKAGES_DATABASE,
+    *PACKAGES_MEDIA,
+    *PACKAGES_FILE_SHARING,
+    *PACKAGES_DEV_UTILS,
+    *PACKAGES_CODE_ANALYSIS,
+    *PACKAGES_PRODUCTIVITY,
+    *PACKAGES_MISC_DEV,
+]
+
 PACKAGE_GROUP2NAMES: dict[PACKAGE_GROUPS, list[str]] = {
-    "ESSENTIAL": PACKAGES_NAMES_ESSENTIAL,
-    "DEV": PACKAGES_NAMES_DEV,
-    "AI_TOOLS": PACKAGES_AI_TOOLS,
-    "TUNNELING": PACKAGES_TUNNELING,
+    "ESSENTIAL": ESSENTIAL,
+    "DEV": DEV,
+    "AI_TOOLS": BUNDLE_AI,
     "TERMINAL_EMULATORS": PACKAGES_TERMINAL_EMULATORS,
     "BROWSERS": PACKAGES_BROWSERS,
     "CODE_EDITORS": PACKAGES_CODE_EDITORS,
-    "PRESENTATION": PACKAGES_PRESENTATION,
     "DATABASE": PACKAGES_DATABASE,
-    "DOC_CONVERSION": PACKAGES_DOC_CONVERSION,
     "MEDIA": PACKAGES_MEDIA,
     "FILE_SHARING": PACKAGES_FILE_SHARING,
-    "GIT_DOCKER_TOOLS": PACKAGES_GIT_DOCKER_TOOLS,
     "DEV_UTILS": PACKAGES_DEV_UTILS,
     "CODE_ANALYSIS": PACKAGES_CODE_ANALYSIS,
     "PRODUCTIVITY": PACKAGES_PRODUCTIVITY,
     "MISC_DEV": PACKAGES_MISC_DEV,
     "SYSTEM_MONITORS": PACKAGES_SYSTEM_MONITORS,
-    "FILE_TOOLS": PACKAGES_FILE_TOOLS,
-    "FILE_VIEWERS": PACKAGES_FILE_VIEWERS,
-    "SEARCH": PACKAGES_SEARCH,
+    "SEARCH": PACKAGES_FILE,
     "TERMINAL_SHELL": PACKAGES_TERMINAL_SHELL,
-    "CLOUD_UTILS": PACKAGES_CLOUD_UTILS,
-    "WEB_TERMINAL": PACKAGES_WEB_TERMINAL,
 }
 
 _ = Union, Literal
