@@ -5,75 +5,30 @@ croshell
 """
 
 from typing import Annotated, Optional
+from machineconfig.scripts.python.helpers_croshell.crosh import code, get_read_data_pycode
+from machineconfig.utils.meta import lambda_to_python_script
 import typer
 from machineconfig.utils.path_extended import PathExtended
+from pathlib import Path
 from machineconfig.utils.accessories import randstr
 import json
-# import shutil
-
 from machineconfig.utils.options import choose_from_options
 from rich.console import Console
 from rich.panel import Panel
-# from machineconfig.utils.ve import get_ve_path_and_ipython_profile
-# from pathlib import Path
-# from rich.text import Text
+
 
 console = Console()
 
 
-def add_print_header_pycode(path: str, title: str):
-    return f"""
-
-from machineconfig.utils.path_extended import PathExtended
-pycode = PathExtended(r'{path}').read_text(encoding="utf-8")
-pycode = pycode.split("except Exception: print(pycode)")[2]
-
-try:
-    from rich.text import Text
-    from rich.panel import Panel
-    from rich.console import Console
-    from rich.syntax import Syntax
-    console = Console()
-    if pycode.strip() != "":
-        console.print(Panel(Syntax(pycode, lexer="python"), title='{title}'), style="bold red")
-except Exception: print(pycode)
-"""
-
-
-def get_read_data_pycode(path: str):
-    return f"""
-from rich.panel import Panel
-from rich.text import Text
-from rich.console import Console
-console = Console()
-p = PathExtended(r'{path}').absolute()
-try:
-    from machineconfig.utils.files.read import Read
-    from machineconfig.utils.accessories import pprint
-    dat = Read.read(p)
-    if isinstance(dat, dict):
-        panel_title = f"📄 File Data: {{p.name}}"
-        console.print(Panel(Text(str(dat), justify="left"), title=panel_title, expand=False))
-        pprint(dat, PathExtended.name)
-    else:
-        panel_title = f"📄 Successfully read the file: {{p.name}}"
-        console.print(Panel(Text(str(dat), justify="left"), title=panel_title, expand=False))
-except Exception as e:
-    error_message = f'''❌ ERROR READING FILE\nFile: {{p.name}}\nError: {{e}}'''
-    console.print(Panel(Text(error_message, justify="left"), title="Error", expand=False, border_style="red"))
-"""
-
-
 def croshell(
     path: Annotated[Optional[str], typer.Argument(help="path of file to read.")] = "",
     python: Annotated[bool, typer.Option("--python", "-p", help="flag to use python over IPython.")] = False,
     profile: Annotated[Optional[str], typer.Option("--profile", "-P", help="ipython profile to use, defaults to default profile.")] = None,
     jupyter: Annotated[bool, typer.Option("--jupyter", "-j", help="run in jupyter interactive console")] = False,
     vscode: Annotated[bool, typer.Option("--vscode", "-c", help="open the script in vscode")] = False,
-    streamlit_viewer: Annotated[bool, typer.Option("--stViewer", "-s", help="view in streamlit app")] = False,
-    visidata: Annotated[bool, typer.Option("--visidata", "-V", help="open data file in visidata")] = False,
+    streamlit_viewer: Annotated[bool, typer.Option("--streamlit", "-s", help="view in streamlit app")] = False,
+    visidata: Annotated[bool, typer.Option("--visidata", "-v", help="open data file in visidata")] = False,
     marimo: Annotated[bool, typer.Option("--marimo", "-m", help="open the notebook using marimo if available")] = False,
-    local: Annotated[bool, typer.Option("--local", "-l", help="run in local mode, not in virtual env.")]= False,
 ) -> None:
     # ==================================================================================
     # flags processing
@@ -103,9 +58,10 @@ def croshell(
             # streamlit run {py_file_path}
             # """
             #             PROGRAM_PATH.write_text(data=final_program, encoding="utf-8")
+            print("Streamlit viewer is not yet implemented in this version.")
             return None
         file_obj = PathExtended(str(path).lstrip()).expanduser().absolute()
-        program = get_read_data_pycode(str(file_obj))
+        program = lambda_to_python_script(lambda: get_read_data_pycode(path=str(file_obj)), in_global=True)
         text = f"📄 Reading data from: {file_obj.name}"
         console.print(Panel(text, title="[bold blue]Info[/bold blue]"))
     else:  # if nothing is specified, then run in interactive mode.
@@ -115,23 +71,29 @@ def croshell(
         # InteractiveShell().run()
         # return None
         program = ""
-
     preprogram = """
-
 #%%
-
-from machineconfig.utils.files.headers import print_header, print_logo
-print_header()
-print_logo("CROCODILE")
-from pathlib import Path
-
 """
+    def preprogram_func():
+        from machineconfig.utils.files.headers import print_header, print_logo
+        print_header()
+        print_logo("CROCODILE")
+        from pathlib import Path
+        from machineconfig.utils.path_extended import PathExtended
+        _ = Path, PathExtended  # avoid unused import warnings
+    import inspect, textwrap
+    from types import FunctionType
+    def get_body_simple_function_no_args(f: FunctionType):
+        return textwrap.dedent("\n".join(inspect.getsource(f).splitlines()[1:]))
+    preprogram += get_body_simple_function_no_args(preprogram_func)
 
     pyfile = PathExtended.tmp().joinpath(f"tmp_scripts/python/croshell/{randstr()}/script.py")
     pyfile.parent.mkdir(parents=True, exist_ok=True)
 
     title = "Reading Data"
-    python_program = preprogram + add_print_header_pycode(str(pyfile), title=title) + program
+    def_code = lambda_to_python_script(lambda: code(path=str(pyfile), title=title), in_global=False)
+    # print(def_code)
+    python_program = preprogram + "\n\n" + def_code + program
     pyfile.write_text(python_program, encoding="utf-8")
     # ve_root_from_file, ipython_profile = get_ve_path_and_ipython_profile(PathExtended(file))
     ipython_profile = ipython_profile if ipython_profile is not None else "default"
@@ -164,34 +126,31 @@ from pathlib import Path
     if visidata:
         fire_line = f"uv run --with visidata,pyarrow vd {str(file_obj)}"
     elif marimo:
+        if Path.home().joinpath("code/machineconfig").exists(): requirements = f"""--with marimo --project "{str(Path.home().joinpath("code/machineconfig"))}" """
+        else: requirements = """--with "marimo,machineconfig[plot]>=6.52" """
         fire_line = f"""
 cd {str(pyfile.parent)}
-uv run --with marimo marimo convert {pyfile.name} -o marimo_nb.py
-uv run --with "marimo,machineconfig[plot]>=6.36" marimo edit --host 0.0.0.0 marimo_nb.py
+uv run --with "marimo" marimo convert {pyfile.name} -o marimo_nb.py
+uv run  {requirements} marimo edit --host 0.0.0.0 marimo_nb.py
 """
     elif jupyter:
-        fire_line = f"uv run --with 'machineconfig[plot]>=6.36' jupyter-lab {str(nb_target)}"
+        if Path.home().joinpath("code/machineconfig").exists(): requirements = f"""--project "{str(Path.home().joinpath("code/machineconfig"))}" --with jupyterlab """
+        else: requirements = """--with "machineconfig[plot]>=6.52" """
+        fire_line = f"uv run {requirements} jupyter-lab {str(nb_target)}"
     elif vscode:
         fire_line = f"""
 cd {str(pyfile.parent)}
 uv init --python 3.14
 uv venv
-uv add "machineconfig[plot]>=6.36"
+uv add "machineconfig[plot]>=6.52"
 # code serve-web
 code --new-window {str(pyfile)}
 """
     else:
         if interpreter == "ipython": profile = f" --profile {ipython_profile} --no-banner"
         else: profile = ""
-        if local:
-            from machineconfig.utils.source_of_truth import LIBRARY_ROOT
-            repo_root = LIBRARY_ROOT.parent.parent
-            if repo_root.parent.name == "code" and repo_root.name == "machineconfig" and repo_root.exists() and repo_root.is_dir():
-                ve_line = f"--project {str(repo_root)}"
-            else:
-                console.print(Panel("❌ Could not determine the local machineconfig repo root. Please ensure the `REPO_ROOT` in `source_of_truth.py` is correctly set to the local path of the machineconfig repo, or do not use the `--local` flag.", title="Error", border_style="red"))
-                return
-        else: ve_line = """--with "machineconfig[plot]>=6.36" """
+        if Path.home().joinpath("code/machineconfig").exists(): ve_line = f"""--project "{str(Path.home().joinpath("code/machineconfig"))}" """
+        else: ve_line = """--with "machineconfig[plot]>=6.52" """
         # ve_path_maybe, ipython_profile_maybe = get_ve_path_and_ipython_profile(Path.cwd())
         # --python 3.14
         fire_line = f"uv run {ve_line} {interpreter} {interactivity} {profile} {str(pyfile)}"
