@@ -6,8 +6,8 @@ import typer
 from machineconfig.utils.path_extended import PathExtended
 from machineconfig.utils.terminal import Response
 from machineconfig.utils.source_of_truth import CONFIG_ROOT, DEFAULTS_PATH
-from machineconfig.utils.code import get_shell_file_executing_python_script, write_shell_script_to_file
-
+from machineconfig.utils.code import get_uv_command_executing_python_script
+from pathlib import Path
 import platform
 import subprocess
 from typing import Optional, Literal, Annotated
@@ -38,12 +38,14 @@ def main(
     repo_local_obj = git.Repo(repo_local_root, search_parent_directories=True)
     repo_local_root = PathExtended(repo_local_obj.working_dir)  # cwd might have been in a sub directory of repo_root, so its better to redefine it.
     PathExtended(CONFIG_ROOT).joinpath("remote").mkdir(parents=True, exist_ok=True)
-    repo_remote_root = PathExtended(CONFIG_ROOT).joinpath("remote", repo_local_root.rel2home())  # .delete(sure=True)
-
+    repo_remote_root = PathExtended(CONFIG_ROOT).joinpath("remote", repo_local_root.rel2home())
+    repo_remote_root.delete(sure=True)
     try:
         console.print(Panel("📥 DOWNLOADING REMOTE REPOSITORY", title_align="left", border_style="blue"))
         remote_path = repo_local_root.get_remote_path(rel2home=True, os_specific=False, root="myhome") + ".zip.enc"
-        repo_remote_root.from_cloud(remotepath=remote_path, cloud=cloud_resolved, unzip=True, decrypt=True, rel2home=True, os_specific=False, pwd=pwd)
+        res = repo_remote_root.from_cloud(remotepath=remote_path, cloud=cloud_resolved, unzip=True, decrypt=True, rel2home=True, os_specific=False, pwd=pwd)
+        if res is None:
+            raise AssertionError("Remote repo does not exist.")
     except AssertionError:
         console.print(Panel("🆕 Remote repository doesn't exist\n📤 Creating new remote and exiting...", title_align="left", border_style="green"))
         repo_local_root.to_cloud(cloud=cloud_resolved, zip=True, encrypt=True, rel2home=True, pwd=pwd, os_specific=False)
@@ -74,7 +76,17 @@ git pull originEnc master
 
 """
 
-    shell_path = write_shell_script_to_file(shell_script=script)
+    if Path.home().joinpath("code/machineconfig").exists():
+        uv_project_dir = f"""{str(Path.home().joinpath("code/machineconfig"))}"""
+        uv_with = None
+    else:
+        uv_with = ["machineconfig>=6.52"]
+        uv_project_dir = None
+
+    import tempfile
+    shell_path = Path(tempfile.mkstemp(suffix=".ps1" if platform.system() == "Windows" else ".sh")[1])
+    shell_path.write_text(script, encoding="utf-8")
+
     command = f". {shell_path}"
     if platform.system() == "Windows":
         completed = subprocess.run(["powershell", "-Command", command], capture_output=True, check=False, text=True)
@@ -95,13 +107,12 @@ git pull originEnc master
 
         # ================================================================================
         option1 = "Delete remote copy and push local:"
+        from machineconfig.utils.meta import lambda_to_python_script
         def func2(remote_repo: str, local_repo: str, cloud: str):
-            from machineconfig.scripts.python.repos_helpers.sync import delete_remote_repo_copy_and_push_local
+            from machineconfig.scripts.python.helpers_repos.sync import delete_remote_repo_copy_and_push_local
             delete_remote_repo_copy_and_push_local(remote_repo=remote_repo, local_repo=local_repo, cloud=cloud)
-            return "done"
-        from machineconfig.utils.meta import function_to_script
-        program_1_py = function_to_script(func=func2, call_with_args=None, call_with_kwargs={"remote_repo": str(repo_remote_root), "local_repo": str(repo_local_root), "cloud": cloud_resolved})
-        shell_file_1 = get_shell_file_executing_python_script(python_script=program_1_py, ve_path=None, executable="""uv run --with "machineconfig>=6.36" """)
+        program_1_py = lambda_to_python_script(lambda: func2(remote_repo=str(repo_remote_root), local_repo=str(repo_local_root), cloud=str(cloud_resolved)), in_global=True)
+        program1, _pyfile1 = get_uv_command_executing_python_script(python_script=program_1_py, uv_with=uv_with, uv_project_dir=uv_project_dir)
         # ================================================================================
         option2 = "Delete local repo and replace it with remote copy:"
         program_2 = f"""
@@ -114,15 +125,19 @@ sudo chmod 600 $HOME/.ssh/*
 sudo chmod 700 $HOME/.ssh
 sudo chmod +x $HOME/dotfiles/scripts/linux -R
 """
-        shell_file_2 = write_shell_script_to_file(shell_script=program_2)
+        import tempfile
+        shell_file_2 = Path(tempfile.mkstemp(suffix=".ps1" if platform.system() == "Windows" else ".sh")[1])
+        shell_file_2.write_text(program_2, encoding="utf-8")
+
         # ================================================================================
         option3 = "Inspect repos:"
         def func(repo_local_root: str, repo_remote_root: str):
-            from machineconfig.scripts.python.repos_helpers.sync import inspect_repos
+            from machineconfig.scripts.python.helpers_repos.sync import inspect_repos
             inspect_repos(repo_local_root=repo_local_root, repo_remote_root=repo_remote_root)
-            return "done"
-        program_3_py = function_to_script(func=func, call_with_args=None, call_with_kwargs={"repo_local_root": str(repo_local_root), "repo_remote_root": str(repo_remote_root)})
-        shell_file_3 = get_shell_file_executing_python_script(python_script=program_3_py, ve_path=None, executable="""uv run --with "machineconfig>=6.36" """)
+        # program_3_py = function_to_script(func=func, call_with_kwargs={"repo_local_root": str(repo_local_root), "repo_remote_root": str(repo_remote_root)})
+        # shell_file_3 = get_shell_file_executing_python_script(python_script=program_3_py, ve_path=None, executable=executable)
+        program_3_py = lambda_to_python_script(lambda: func(repo_local_root=str(repo_local_root), repo_remote_root=str(repo_remote_root)), in_global=True)
+        program3, _pyfile3 = get_uv_command_executing_python_script(python_script=program_3_py, uv_with=uv_with, uv_project_dir=uv_project_dir)
         # ================================================================================
 
         option4 = "Remove problematic rclone file from repo and replace with remote:"
@@ -131,16 +146,17 @@ rm $HOME/dotfiles/creds/rclone/rclone.conf
 cp $HOME/.config/machineconfig/remote/dotfiles/creds/rclone/rclone.conf $HOME/dotfiles/creds/rclone
 cd $HOME/dotfiles
 git commit -am "finished merging"
-. {shell_file_1}
+{program1}
 """
-        shell_file_4 = write_shell_script_to_file(shell_script=program_4)
+        shell_file_4 = Path(tempfile.mkstemp(suffix=".ps1" if platform.system() == "Windows" else ".sh")[1])
+        shell_file_4.write_text(program_4, encoding="utf-8")
         # ================================================================================
 
         console.print(Panel("🔄 RESOLVE MERGE CONFLICT\nChoose an option to resolve the conflict:", title_align="left", border_style="blue"))
 
-        print(f"• {option1:75} 👉 {shell_file_1}")
+        print(f"• {option1:75} 👉 {program1}")
         print(f"• {option2:75} 👉 {shell_file_2}")
-        print(f"• {option3:75} 👉 {shell_file_3}")
+        print(f"• {option3:75} 👉 {program3}")
         print(f"• {option4:75} 👉 {shell_file_4}")
         print("\n\n")
 
@@ -150,21 +166,21 @@ git commit -am "finished merging"
                 import questionary
                 choice = questionary.select("Choose one option:", choices=[option1, option2, option3, option4]).ask()
                 if choice == option1:
-                    program_content = shell_file_1.read_text(encoding="utf-8")
+                    program_content = program1
                 elif choice == option2:
                     program_content = program_2
                 elif choice == option3:
-                    program_content = shell_file_3.read_text(encoding="utf-8")
+                    program_content = program3
                 elif choice == option4:
                     program_content = program_4
                 else:
                     raise NotImplementedError(f"Choice {choice} not implemented.")
             case "push-local-merge":
-                program_content = shell_file_1.read_text(encoding="utf-8")
+                program_content = program1
             case "overwrite-local":
                 program_content = program_2
             case "stop-on-conflict":
-                program_content = shell_file_3.read_text(encoding="utf-8")
+                program_content = program3
             case "remove-rclone-conflict":
                 program_content = program_4
             case _:
