@@ -2,8 +2,7 @@
 from pathlib import Path
 
 APPS = Path(__file__).parent.joinpath("apps.sh")
-REPOS = Path(__file__).parent.joinpath("repos.sh")
-VE = Path(__file__).parent.joinpath("ve.sh")
+UV = Path(__file__).parent.joinpath("uv.sh")
 
 APPS_DESKTOP = Path(__file__).parent.joinpath("apps_desktop.sh")
 APPS_GUI = Path(__file__).parent.joinpath("apps_gui.sh")
