@@ -1,7 +1,7 @@
 #!/bin/bash
 . <( curl -sSL "https://raw.githubusercontent.com/thisismygitrepo/machineconfig/main/src/machineconfig/setup_linux/uv.sh")
 mcfg() {
-    "$HOME/.local/bin/uv" run --python 3.14 --with "machineconfig>=6.36" mcfg "$@"
+    "$HOME/.local/bin/uv" run --python 3.14 --with "machineconfig>=6.52" mcfg "$@"
 }
 alias d="mcfg devops"
 alias c="mcfg cloud"
@@ -9,5 +9,5 @@ alias a="mcfg agents"
 alias s="mcfg sessions"
 alias ff="mcfg ftpx"
 alias f="mcfg fire"
-alias cs="mcfg croshell"
+alias r="mcfg croshell"
 echo "mcfg command is now defined in this shell session."
